@@ -13,7 +13,7 @@ from . import (
     ReadingEnumFailed,
     utils,
 )
-from .constants import WIZARD_SPEED, ntdll
+from .constants import WIZARD_SPEED
 from .memory import (
     CurrentActorBody,
     CurrentClientObject,
@@ -21,6 +21,7 @@ from .memory import (
     CurrentGameStats,
     CurrentQuestPosition,
     CurrentRootWindow,
+    CurrentGameClient,
     DuelPhase,
     HookHandler,
     CurrentRenderContext,
@@ -63,6 +64,7 @@ class Client:
         self.client_object = CurrentClientObject(self.hook_handler)
         self.root_window = CurrentRootWindow(self.hook_handler)
         self.render_context = CurrentRenderContext(self.hook_handler)
+        self.game_client = CurrentGameClient(self.hook_handler)
 
         self._teleport_helper = TeleportHelper(self.hook_handler)
 
@@ -397,8 +399,9 @@ class Client:
             xyz: XYZ,
             yaw: float = None,
             *,
-            move_after: bool = True,
+            move_after: bool = False,
             wait_on_inuse: bool = False,
+            wait_for_done: bool = True,
     ):
         """
         Teleport the client
@@ -458,12 +461,12 @@ class Client:
             if not wait_on_inuse:
                 raise ValueError("Tried to teleport while should update bool is set")
 
-            await wait_for_value(self._teleport_helper.should_update, True)
+            await wait_for_value(self._teleport_helper.should_update, False)
 
         jes = await self._get_je_instruction_forward_backwards()
 
         if not self.hook_handler._check_if_hook_active(MovementTeleportHook):
-            raise RuntimeError("MOVEMENT TELEPORT NOT ACTIVE")
+            raise RuntimeError("Movement teleport not active")
 
         await self._teleport_helper.write_target_object_address(object_address)
         await self._teleport_helper.write_position(xyz)
